==> progamification-0.0.6.tar.gz: lib/src/components/leaderboard_info.dart <==
import 'package:flutter/material.dart';
import 'package:progamification/src/components/achievements.dart';
import 'package:progamification/src/components/leaderboard_table.dart';

class LeaderboardInfo extends StatefulWidget {
  const LeaderboardInfo({super.key});

  @override
  State<LeaderboardInfo> createState() => _LeaderboardInfoState();
}

class _LeaderboardInfoState extends State<LeaderboardInfo>
    with SingleTickerProviderStateMixin {
  late TabController _controller;
  @override
  void initState() {
    super.initState();
    _controller = TabController(
      initialIndex: 0,
      length: 2,
      vsync: this,
    );
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
        height: MediaQuery.of(context).size.height * 0.8,
        child: SingleChildScrollView(
            child: Column(
          children: [
            Container(
              width: MediaQuery.of(context).size.width,
              padding: EdgeInsets.only(
                  top: MediaQuery.of(context).size.height * 0.02,
                  bottom: MediaQuery.of(context).size.height * 0.02),
              decoration: const BoxDecoration(
                color: Color(0xFF2d6ac2),
              ),
              child: const Center(
                child: Padding(
                  padding: EdgeInsets.all(8.0),
                  child: Text(
                    "Activity",
                    style: TextStyle(
                      color: Colors.white,
                      fontWeight: FontWeight.w600,
                      fontSize: 16,
                    ),
                  ),
                ),
              ),
            ),
            Container(
              decoration: const BoxDecoration(color: Color(0xFF2d6ac2)),
              child: TabBar(
                indicatorColor: Colors.white,
                indicatorSize: TabBarIndicatorSize.tab,
                indicatorWeight: 3.0,
                controller: _controller,
                tabs: const [
                  Padding(
                    padding: EdgeInsets.all(4.0),
                    child: Tab(
                      child: FittedBox(
                        fit: BoxFit.fitWidth,
                        child: Text(
                          "Achievements",
                          style: TextStyle(
                            color: Colors.white,
                            fontSize: 15,
                            fontFamily: 'Roboto',
                            letterSpacing: 0.5,
                          ),
                        ),
                      ),
                    ),
                  ),
                  Padding(
                    padding: EdgeInsets.all(4.0),
                    child: Tab(
                      child: FittedBox(
                        fit: BoxFit.fitWidth,
                        child: Text(
                          "Leaderboard",
                          style: TextStyle(
                            color: Colors.white,
                            fontSize: 15,
                            fontFamily: 'Roboto',
                            letterSpacing: 1,
                          ),
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ),
            SizedBox(
              height: MediaQuery.of(context).size.height * 0.8,
              child: TabBarView(
                controller: _controller,
                children: const [
                  Achievements(),
                  LeaderBoardTable(),
                ],
              ),
            ),
          ],
        )));
  }
}

==> progamification-0.0.38.tar.gz: lib/src/components/leaderboard_info.dart <==
import 'package:flutter/material.dart';
import 'package:progamification/src/components/achievements.dart';
import 'package:progamification/src/components/leaderboard_table.dart';

class LeaderboardInfo extends StatefulWidget {
  const LeaderboardInfo({super.key});

  @override
  State<LeaderboardInfo> createState() => _LeaderboardInfoState();
}

class _LeaderboardInfoState extends State<LeaderboardInfo>
    with SingleTickerProviderStateMixin {
  late TabController _controller;
  @override
  void initState() {
    super.initState();
    _controller = TabController(
      initialIndex: 0,
      length: 2,
      vsync: this,
    );
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
        height: MediaQuery.of(context).size.height * 0.8,
        child: SingleChildScrollView(
            child: Column(
          children: [
            Container(
              decoration: const BoxDecoration(color: Colors.white),
              child: TabBar(
                indicatorColor: Colors.black,
                indicatorSize: TabBarIndicatorSize.tab,
                indicatorWeight: 3.0,
                controller: _controller,
                tabs: const [
                  Padding(
                    padding: EdgeInsets.all(2.0),
                    child: Tab(
                      child: FittedBox(
                        fit: BoxFit.fitWidth,
                        child: Text(
                          "Achievements",
                          style: TextStyle(
                              color: Colors.black,
                              fontSize: 16,
                              fontFamily: 'Roboto',
                              letterSpacing: 0.5,
                              fontWeight: FontWeight.bold),
                        ),
                      ),
                    ),
                  ),
                  Padding(
                    padding: EdgeInsets.all(2.0),
                    child: Tab(
                      child: FittedBox(
                        fit: BoxFit.fitWidth,
                        child: Text(
                          "Leaderboard",
                          style: TextStyle(
                              color: Colors.black,
                              fontSize: 16,
                              fontFamily: 'Roboto',
                              letterSpacing: 1,
                              fontWeight: FontWeight.bold),
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ),
            SizedBox(
              height: MediaQuery.of(context).size.height * 0.8,
              child: TabBarView(
                controller: _controller,
                children: const [
                  Achievements(),
                  LeaderBoardTable(),
                ],
              ),
            ),
          ],
        )));
  }
}
